==> pyconnectwise-0.4.5.tar.gz: pyconnectwise-0.4.5/src/pyconnectwise/endpoints/manage/ProcurementCatalogIdMinimumstockbywarehouseEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.ProcurementCatalogIdMinimumstockbywarehouseCountEndpoint import \
    ProcurementCatalogIdMinimumstockbywarehouseCountEndpoint
from pyconnectwise.endpoints.manage.ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint import \
    ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint
from pyconnectwise.models.manage import MinimumStockByWarehouse
from pyconnectwise.responses.paginated_response import PaginatedResponse


class ProcurementCatalogIdMinimumstockbywarehouseEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "minimumStockByWarehouse", parent_endpoint=parent_endpoint)

        self.count = self._register_child_endpoint(
            ProcurementCatalogIdMinimumstockbywarehouseCountEndpoint(client, parent_endpoint=self)
        )

    def id(self, id: int) -> ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint: The initialized ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint object.
        """
        child = ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: dict[str, int | str] = {}
    ) -> PaginatedResponse[MinimumStockByWarehouse]:
        """
        Performs a GET request against the /procurement/catalog/{id}/minimumStockByWarehouse endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[MinimumStockByWarehouse]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params),
            MinimumStockByWarehouse,
            self,
            page,
            page_size,
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[MinimumStockByWarehouse]:
        """
        Performs a GET request against the /procurement/catalog/{id}/minimumStockByWarehouse endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[MinimumStockByWarehouse]: The parsed response data.
        """
        return self._parse_many(MinimumStockByWarehouse, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> MinimumStockByWarehouse:
        """
        Performs a POST request against the /procurement/catalog/{id}/minimumStockByWarehouse endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            MinimumStockByWarehouse: The parsed response data.
        """
        return self._parse_one(MinimumStockByWarehouse, super()._make_request("POST", data=data, params=params).json())

==> pyconnectwise-0.4.7.tar.gz: pyconnectwise-0.4.7/src/pyconnectwise/endpoints/manage/ProcurementCatalogIdMinimumstockbywarehouseEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.ProcurementCatalogIdMinimumstockbywarehouseCountEndpoint import \
    ProcurementCatalogIdMinimumstockbywarehouseCountEndpoint
from pyconnectwise.endpoints.manage.ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint import \
    ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint
from pyconnectwise.models.manage import MinimumStockByWarehouse
from pyconnectwise.responses.paginated_response import PaginatedResponse


class ProcurementCatalogIdMinimumstockbywarehouseEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "minimumStockByWarehouse", parent_endpoint=parent_endpoint)

        self.count = self._register_child_endpoint(
            ProcurementCatalogIdMinimumstockbywarehouseCountEndpoint(client, parent_endpoint=self)
        )

    def id(self, id: int) -> ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint: The initialized ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint object.
        """
        child = ProcurementCatalogIdMinimumstockbywarehouseIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: dict[str, int | str] = {}
    ) -> PaginatedResponse[MinimumStockByWarehouse]:
        """
        Performs a GET request against the /procurement/catalog/{id}/minimumStockByWarehouse endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[MinimumStockByWarehouse]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params), MinimumStockByWarehouse, self, page, page_size, params
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[MinimumStockByWarehouse]:
        """
        Performs a GET request against the /procurement/catalog/{id}/minimumStockByWarehouse endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[MinimumStockByWarehouse]: The parsed response data.
        """
        return self._parse_many(MinimumStockByWarehouse, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> MinimumStockByWarehouse:
        """
        Performs a POST request against the /procurement/catalog/{id}/minimumStockByWarehouse endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            MinimumStockByWarehouse: The parsed response data.
        """
        return self._parse_one(MinimumStockByWarehouse, super()._make_request("POST", data=data, params=params).json())
